Learn R Programming

ETAS (version 0.2)

etas.object: Class of Fitted ETAS Models

Description

A class etas to represent a fitted ETAS model. The output of etas.

Arguments

Details

An object of class etas represents an ETAS model that has been fitted to a spatio-temporal point pattern (catalog) of earthquakes. It is the output of the model fitter, etas.

The class etas has methods for the following standard generic functions:

generic method
description print
print.etas print details

See Also

etas,

Examples

Run this code
  # fitting the ETAS model to an Iranian catalog

  data(iran.quakes)
  summary(iran.quakes)

  # preparing the catalog
  iran.cat <- catalog(iran.quakes, time.begin="1973/01/01",
     study.start="1985/01/01", study.end="2016/01/01",
     lat.range=c(25, 42), long.range=c(42, 63), mag.threshold=4.5)

  ## Not run: 
#   plot(ir.cat)
#   ## End(Not run)

  # initial parameters values
  param01 <- c(0.4339678,
   0.1988628,
   0.0345206,
   1.6290137,
   1.1286776,
   0.0072539,
   2.1705884,
   0.5706402)

  # fitting the model
  ## Not run: 
#   res <- etas(ir.cat, param0=param01, no.itr=5)
#   ## End(Not run)

Run the code above in your browser using DataLab