Learn R Programming

ETAS (version 0.2)

iran.quakes: An Iranian Earthquake Catalog

Description

A data frame with 5970 rows and 5 columns giving occurrence date, time, longitude, latitude and magnitude of shallow earthquakes (depth < 100 km) occurred since 1973-01-01 till 2016-01-01 in Iran and its vicinity (40-65E and 22-42N). Only earthquakes with magnitude greater than or equal to 4.5 are included.

Usage

data(iran.quakes)

Arguments

Format

An object of class "data.frame" containing the following columns:
  • date Occurrence date in the format "yyyy-mm-dd"
  • time Occurrence time (UTC) in the format "hh:mm:ss"
  • long Latitude of epicenter in decimal degrees
  • lat Latitude of epicenter in decimal degrees
  • mag Magnitude in body-wave magnitude scale (mb)

The ANSS Comprehensive Catalog (ComCat): http://earthquake.usgs.gov/earthquakes/search/

References

Jalilian, A. (2016). Modeling Earthquakes of Iran.