Learn R Programming

ETAS (version 0.2)

lambda: Clustering Part of Conditional Intensity Function of the ETAS Model

Description

A function to compute the clustering part of the conditional intensity function of the ETAS model at specified time and location.

Usage

lambda(t, x, y, param, object)

Arguments

t
A numeric value. The time that the conditional intensity is to be computed at.
x
A numeric value. The x-coordinate of the location that the conditional intensity is to be computed at.
y
A numeric value. The y-coordinate of the location that the conditional intensity is to be computed at.
param
Vector of model paramters.
object
An object of class "catalog" containing an earthquake catalog dataset.

Value

A numeric value.

Details

For a given $t$, $x$ and $y$, this function computes $$ \sum_{t_i < t} k(m_i)g(t - t_i)f(x - x_i, y - y_i|m_i).$$

References

Zhuang, J., Ogata, Y. and Vere-Jones, D. (2005). Diagnostic analysis of space-time branching processes for earthquakes. Lecture Note in Statistics: Case Studies in Spatial Point Process Models (Baddeley, A., Gregori, P., Mateu, J., Stoica, R. and Stoyan, D.), Springer-Verlag, New York, 185, 276--292.

Zhuang, J., Ogata, Y. and Vere-Jones, D. (2002). Stochastic declustering of space-time earthquake occurrences. Journal of the American Statistical Association, 97, 369--380.

See Also

etas catalog

Examples

Run this code

  iran.cat <- catalog(iran.quakes, time.begin="1973/01/01",
     study.start="1996/01/01", study.end="2016/01/01",
     lat.range=c(25, 42), long.range=c(42, 63), mag.threshold=4.5)

  param <- c(0.46, 0.23, 0.022, 2.8, 1.12, 0.012, 2.4, 0.35)

  ## Not run: 
#   lambda(15706, 40.12, 34.5, param, iran.cat)## End(Not run)

Run the code above in your browser using DataLab